TODO
====

- move LDAP related code to ``cone.ldap``
- make UI work with any kind of ``node.ext.ugm`` based implementations.
- provide application model for ``node.ext.ugm.file`` implementation as default.
- Listing batches.
- DnD membership assignment